<?php
// This file is part of Moodle - https://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <https://www.gnu.org/licenses/>.

/**
 * Strings for component 'assignsubmission_estream', language 'id', version '5.0'.
 *
 * @package     assignsubmission_estream
 * @category    string
 * @copyright   1999 Martin Dougiamas and contributors
 * @license     https://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

$string['currentsubmission'] = 'Pengiriman Saat Ini';
$string['default'] = 'Diaktifkan secara default';
$string['default_help'] = 'Jika disetel, metode pengiriman ini akan diaktifkan secara default untuk semua tugas yang baru dibuat.';
$string['enabled'] = 'Planet eStream Submissions diaktifkan';
$string['enabled_help'] = 'Jika diaktifkan, siswa dapat mengirimkan file video / audio yang diunggah untuk penilaian melalui Planet eStream saat menggunakan plugin editor teks.';
$string['nosubmission'] = 'Belum ada yang dikirimkan';
$string['notyetconfigured'] = 'Maaf, Plugin Pengajuan Tugas eStream Planet belum dikonfigurasi.';
$string['pluginname'] = 'Plugin Planet eStream Submission';
$string['settingsurl'] = 'URL Planet eStream';
$string['settingsurl_help'] = 'Masukkan URL ke server Planet eStream Anda. <br /> mis. http://videoserver.mysite.org <br /> atau https://videoserver.mysite.org <br /> <br /> Perlu diketahui bahwa jika Moodle Anda diakses melalui tautan https maka URL di atas juga harus https';
$string['shortname'] = 'Pengiriman Video / Audio';
$string['upload'] = 'Unggah file Video atau Audio';
$string['upload_help'] = 'Klik tombol Browse, pilih file video atau audio yang akan diupload, lalu klik Upload. <br /> Setelah diupload, file akan tersedia setelah diproses oleh sistem. Harap perhatikan bahwa unggahan yang lebih besar membutuhkan waktu pemrosesan yang lebih lama dan mungkin membutuhkan beberapa waktu untuk ditampilkan di sistem. <br />';
$string['uploadfailed'] = 'Upload Gagal <br /> <br /> Muat ulang halaman dan coba lagi';
$string['uploadok'] = 'Oke diunggah <br /> <br /> Silakan klik & apos; Simpan perubahan & apos; untuk menyelamatkan.';
